@@ -28,7 +28,6 @@
 #include "Itemlist.h"
 #include "templelist.h"
 #include "signpostlist.h"
-#include "stonelist.h"
 #include "portlist.h"
 #include "bridgelist.h"
 #include "roadlist.h"
@@ -65,7 +64,6 @@ CreateScenario::CreateScenario()
     Templelist::deleteInstance();
     Ruinlist::deleteInstance();
     Rewardlist::deleteInstance();
-    Stonelist::deleteInstance();
     Portlist::deleteInstance();
     Bridgelist::deleteInstance();
     Citylist::deleteInstance();
@@ -188,16 +186,6 @@ void CreateScenario::setNoSignposts (int nosignposts)
     d_generator->setNoSignposts(nosignposts);
 }
 
-void CreateScenario::setNoStones(int nostones)
-{
-    debug("CreateScenario::setNoStones")
-
-    if (!d_generator)
-        setMaptype(NORMAL);
-
-    d_generator->setNoStones(nostones);
-}
-
 void CreateScenario::setNoTemples(int notemples)
 {
     debug("CreateScenario::setNoTemples")
@@ -297,14 +285,6 @@ int CreateScenario::getNoRuins() const
     return d_generator->getNoRuins();
 }
 
-int CreateScenario::getNoStones() const
-{
-    if (!d_generator)
-        return -1;
-
-    return d_generator->getNoStones();
-}
-
 int CreateScenario::getNoTemples() const
 {
     if (!d_generator)
@@ -349,7 +329,7 @@ bool CreateScenario::create(const GameParameters &g)
     if (!distributePlayers())
         return false;
 
-    if (!setupCities(g.quick_start))
+    if (!setupCities(g.quick_start, g.cities_can_produce_allies))
         return false;
 
     if (!setupTemples())
@@ -364,6 +344,9 @@ bool CreateScenario::create(const GameParameters &g)
     if (!setupPlayers())
         return false;
 
+    if (!setupRewards())
+        return false;
+
     return true;
 }
 
@@ -391,7 +374,7 @@ bool CreateScenario::createMap()
     //...fill the terrain...
     GameMap::getInstance(d_tilesname)->fill(d_generator);
 
-    //...and create cities, temples, ruins ,signposts, and stones
+    //...and create cities, temples, ruins ,signposts
     map = d_generator->getBuildings(d_width, d_height);
     
     for (int y = 0; y < d_height; y++)
@@ -399,9 +382,6 @@ bool CreateScenario::createMap()
         {
             switch (map[y*d_width + x])
             {
-                case Maptile::STONE:
-                    Stonelist::getInstance()->push_back(Stone(Vector<int>(x,y)));
-                    break;
                 case Maptile::SIGNPOST:
                     Signpostlist::getInstance()->push_back(Signpost(Vector<int>(x,y)));
                     break;
@@ -474,7 +454,8 @@ bool CreateScenario::distributePlayers()
     return true;
 }
 
-bool CreateScenario::setupCities(bool quick_start)
+bool CreateScenario::setupCities(bool quick_start, 
+				 bool cities_can_produce_allies)
 {
     debug("CreateScenario::setupCities")
 
@@ -527,13 +508,13 @@ bool CreateScenario::setupCities(bool quick_start)
         //2. distribute the income a bit (TBD)
 
         //3. set the city production
-        (*it).setRandomArmytypes();
+        (*it).setRandomArmytypes(cities_can_produce_allies);
         if ((*it).getPlayer() == Playerlist::getInstance()->getNeutral())
         {
             switch (GameScenario::s_neutral_cities)
               {
               case GameParameters::AVERAGE:
-                (*it).produceWeakestArmy();
+                (*it).produceScout();
                 break;
               case GameParameters::STRONG:
                 (*it).produceStrongestArmy();
@@ -555,9 +536,14 @@ bool CreateScenario::setupCities(bool quick_start)
             (*it).produceWeakestArmy();
 
             (*it).setProduction(0);
-            //raise the city defense to the highest level
-            for (; (*it).raiseDefense(););
         }
+
+	if (rand() % 2 == 0)
+	  (*it).raiseDefense();
+	if ((*it).isCapital())
+	  (*it).setGold(33 + (rand() % 8));
+	else
+	  (*it).setGold(15 + (rand() % 12));
     }
 
     return true;
@@ -633,6 +619,7 @@ bool CreateScenario::setupRuins(bool strongholds_invisible)
             continue;
           }
 
+
         //one in ten ruins doesn't have a guardian
         if (rand() % 10 == 0 && (*it).getType() == Ruin::RUIN) 
           continue;
@@ -759,3 +746,99 @@ bool CreateScenario::loadNames(std::vector<std::string>& list, std::ifstream& na
 
     return true;
 }
+
+bool CreateScenario::setupRewards()
+{
+  debug("CreateScenario::setupRewards")
+  setupItemRewards();
+  setupRuinRewards();
+  setupMapRewards();
+  return true;
+}
+
+bool CreateScenario::setupMapRewards()
+{
+  debug("CreateScenario::setupMapRewards")
+  if (GameScenario::s_hidden_map == false)
+    return true;
+  //okay, let's make some maps
+  //split the terrain into a 3x3 grid
+  Uint32 h_count = 0;
+  Uint32 w_count = 0;
+  for (int i = 0; i < GameMap::getHeight(); i += (GameMap::getHeight() / 3))
+    {
+      for (int j = 0; j < GameMap::getWidth(); j += (GameMap::getWidth() / 3))
+	{
+	  char *name = NULL;
+	  if (h_count == 0 && j == 0)
+	    name = _("northwestern map");
+	  else if (h_count == 0 && w_count == 1)
+	    name = _("northern map");
+	  else if (h_count == 0 && w_count == 2)
+	    name = _("northeastern map");
+	  else if (h_count == 1 && w_count == 0)
+	    name = _("western map");
+	  else if (h_count == 1 && w_count == 1)
+	    name = _("central map");
+	  else if (h_count == 1 && w_count == 2)
+	    name = _("eastern map");
+	  else if (h_count == 2 && w_count == 0)
+	    name = _("southwestern map");
+	  else if (h_count == 2 && w_count == 1)
+	    name = _("southern map");
+	  else if (h_count == 2 && w_count == 2)
+	    name = _("southeastern map");
+	  else
+	    continue;
+
+	  Vector<int> pos;
+	  pos.x = i;
+	  pos.y = j;
+	  Location *loc = new Location(name, pos);
+	  Reward_Map *reward = new Reward_Map(loc, 
+					      GameMap::getHeight() / 3, 
+					      GameMap::getWidth() / 3);
+	  Rewardlist::getInstance()->push_back(reward); //add it
+	  w_count++;
+	}
+      w_count = 0;
+      h_count++;
+    }
+  return true;
+}
+bool CreateScenario::setupRuinRewards()
+{
+  debug("CreateScenario::setupRuinRewards")
+    for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
+	 it != Ruinlist::getInstance()->end(); it++)
+      {
+	if ((*it).isHidden() == true)
+	  {
+	    //add it to the reward list
+	    Reward_Ruin *newReward = new Reward_Ruin(&(*it)); //make a reward
+	    Rewardlist::getInstance()->push_back(newReward); //add it
+	  }
+	if ((*it).hasSage() == false)
+	  (*it).populateWithRandomReward();
+      }
+  return true;
+}
+
+bool CreateScenario::setupItemRewards()
+{
+  debug("CreateScenario::setupItemRewards")
+    Itemlist::createInstance();
+  Itemlist *il = Itemlist::getInstance();
+  Itemlist::iterator iter;
+  for (iter = il->begin(); iter != il->end(); iter++)
+    {
+      Item templateItem = *iter->second;
+      Item *newItem = new Item(templateItem); //instantiate it
+      Reward_Item *newReward = new Reward_Item(newItem); //make a reward
+      Rewardlist::getInstance()->push_back(newReward); //add it
+    }
+
+  Itemlist::deleteInstance();
+  return true;
+}
+
