@@ -25,7 +25,6 @@
 #include "ruinlist.h"
 #include "rewardlist.h"
 #include "templelist.h"
-#include "stonelist.h"
 #include "bridgelist.h"
 #include "portlist.h"
 #include "roadlist.h"
@@ -34,6 +33,7 @@
 #include "ruin.h"
 #include "File.h"
 #include "armysetlist.h"
+#include "tilesetlist.h"
 #include "stacklist.h"
 #include "GameMap.h"
 #include "player.h"
@@ -45,7 +45,6 @@
 #include "army.h"
 #include "QuestsManager.h"
 #include "Itemlist.h"
-#include "rewardlist.h"
 #include "string_tokenizer.h"
 #include "player.h"
 #include "vectoredunitlist.h"
@@ -70,11 +69,13 @@ GameScenario::GameScenario(std::string name,std::string comment, bool turnmode)
     :d_round(0), d_name(name),d_comment(comment), d_turnmode(turnmode)
 {
     Armysetlist::getInstance();
+    Armysetlist::getInstance()->instantiatePixmaps();
+    Tilesetlist::getInstance();
+    Tilesetlist::getInstance()->instantiatePixmaps();
     Itemlist::createInstance();
 
     if (fl_counter == 0)
         fl_counter = new FL_Counter();
-    setupRewards();
 }
 
 // savegame is a filename with absolute path!
@@ -83,6 +84,9 @@ GameScenario::GameScenario(string savegame, bool& broken)
     :d_turnmode(true)
 {
     Armysetlist::getInstance();
+    Armysetlist::getInstance()->instantiatePixmaps();
+    Tilesetlist::getInstance();
+    Tilesetlist::getInstance()->instantiatePixmaps();
     Itemlist::createInstance();
 
     broken = false;
@@ -96,7 +100,6 @@ GameScenario::GameScenario(string savegame, bool& broken)
     helper.registerTag("ruinlist", sigc::mem_fun(this, &GameScenario::load));
     helper.registerTag("rewardlist", sigc::mem_fun(this, &GameScenario::load));
     helper.registerTag("signpostlist", sigc::mem_fun(this, &GameScenario::load));
-    helper.registerTag("stonelist", sigc::mem_fun(this, &GameScenario::load));
     helper.registerTag("roadlist", sigc::mem_fun(this, &GameScenario::load));
     helper.registerTag("counter", sigc::mem_fun(this, &GameScenario::load));
     helper.registerTag("questlist", sigc::mem_fun(this, &GameScenario::load));
@@ -112,7 +115,6 @@ GameScenario::GameScenario(string savegame, bool& broken)
 
     helper.close();
     GameMap::getInstance()->calculateBlockedAvenues();
-    setupRewards();
 }
 
 GameScenario::~GameScenario()
@@ -125,11 +127,12 @@ GameScenario::~GameScenario()
     Ruinlist::deleteInstance();
     Rewardlist::deleteInstance();
     Signpostlist::deleteInstance();
-    Stonelist::deleteInstance();
     Portlist::deleteInstance();
     Bridgelist::deleteInstance();
+    Roadlist::deleteInstance();
     QuestsManager::deleteInstance();
     Itemlist::deleteInstance();
+    VectoredUnitlist::deleteInstance();
 
     if (fl_counter)
     {
@@ -213,7 +216,6 @@ bool GameScenario::saveGame(string filename, string extension) const
     retval &= Ruinlist::getInstance()->save(&helper);
     retval &= Rewardlist::getInstance()->save(&helper);
     retval &= Signpostlist::getInstance()->save(&helper);
-    retval &= Stonelist::getInstance()->save(&helper);
     retval &= Roadlist::getInstance()->save(&helper);
     retval &= Portlist::getInstance()->save(&helper);
     retval &= Bridgelist::getInstance()->save(&helper);
@@ -346,13 +348,6 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
         return true;
     }
 
-    if (tag == "stonelist")
-    {
-        debug("loading stones")
-        Stonelist::getInstance(helper);
-        return true;
-    }
-
     if (tag == "roadlist")
     {
         debug("loading roads")
@@ -391,45 +386,3 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
     return false;
 }
 
-bool GameScenario::setupRewards()
-{
-  debug("GameScenario::setupRewards")
-  setupItemRewards();
-  setupRuinRewards();
-  return true;
-}
-
-bool GameScenario::setupRuinRewards()
-{
-    debug("GameScenario::setupRuinRewards")
-    for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
-        it != Ruinlist::getInstance()->end(); it++)
-    {
-      if ((*it).isHidden() == true)
-        {
-          //add it to the reward list
-          Reward_Ruin *newReward = new Reward_Ruin(&(*it)); //make a reward
-          Rewardlist::getInstance()->push_back(newReward); //add it
-        }
-    }
-  return true;
-}
-
-bool GameScenario::setupItemRewards()
-{
-    debug("GameScenario::setupItemRewards")
-    Itemlist::createInstance();
-    Itemlist *il = Itemlist::getInstance();
-    Itemlist::iterator iter;
-    for (iter = il->begin(); iter != il->end(); iter++)
-      {
-        Item templateItem = *iter->second;
-        Item *newItem = new Item(templateItem); //instantiate it
-        Reward_Item *newReward = new Reward_Item(newItem); //make a reward
-        Rewardlist::getInstance()->push_back(newReward); //add it
-      }
-
-    Itemlist::deleteInstance();
-    return true;
-}
-
