@@ -39,7 +39,6 @@ struct ArmyCacheItem
     Uint32 armyset;
     Uint32 index;
     const Player* player;
-    int level;
     bool medals[3];
     SDL_Surface* surface;
 };
@@ -65,6 +64,13 @@ struct TempleCacheItem
     SDL_Surface* surface;
 };
 
+//the structure to store ruins in
+struct RuinCacheItem
+{
+    int type;
+    SDL_Surface* surface;
+};
+
 //the structure to store roads in
 struct RoadCacheItem
 {
@@ -93,13 +99,6 @@ struct CursorCacheItem
     SDL_Surface* surface;
 };
 
-//the structure to store stones in
-struct StoneCacheItem
-{
-    int type;
-    SDL_Surface* surface;
-};
-
 //the structure to store buildings in
 struct CityCacheItem
 {
@@ -180,10 +179,8 @@ GraphicsCache::GraphicsCache()
 {
     loadCityPics();
     loadTowerPics();
-    loadShipPic();
-    loadPlantedStandardPic();
     loadTemplePics();
-    loadStonePics();
+    loadRuinPics();
     loadRoadPics();
     loadFogPics();
     loadBridgePics();
@@ -194,7 +191,6 @@ GraphicsCache::GraphicsCache()
     loadProdShields();
     loadMoveBonusPics();
 
-    d_levelmask = File::getMiscPicture("level_mask.png");
     d_medalsmask = File::getMiscPicture("medals_mask.gif");
     d_smallruinedcity = File::getMiscPicture("smallruinedcity.png");
     d_smallhero = File::getMiscPicture("hero.png");
@@ -203,7 +199,7 @@ GraphicsCache::GraphicsCache()
       File::getMiscPicture("smallunexploredstronghold.png");
     d_small_ruin_explored = File::getMiscPicture("smallexploredruin.png");
     d_small_temple = File::getMiscPicture("smalltemple.png");
-    std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+    std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
     d_port = File::getMapsetPicture(tileset, "misc/port.png");
 }
 
@@ -263,7 +259,6 @@ GraphicsCache::~GraphicsCache()
         SDL_FreeSurface(d_movebonuspic[i]);
     }
 
-    SDL_FreeSurface(d_levelmask);
     SDL_FreeSurface(d_medalsmask);
     SDL_FreeSurface(d_smallruinedcity);
     SDL_FreeSurface(d_smallhero);
@@ -271,10 +266,6 @@ GraphicsCache::~GraphicsCache()
     SDL_FreeSurface(d_small_ruin_unexplored);
     SDL_FreeSurface(d_small_stronghold_unexplored);
     SDL_FreeSurface(d_small_ruin_explored);
-    SDL_FreeSurface(d_ship);
-    SDL_FreeSurface(d_shipmask);
-    SDL_FreeSurface(d_planted_standard);
-    SDL_FreeSurface(d_planted_standard_mask);
     SDL_FreeSurface(d_port);
 }
 
@@ -403,7 +394,7 @@ SDL_Surface* GraphicsCache::getPlantedStandardPic(const Player* p)
 }
 
 SDL_Surface* GraphicsCache::getArmyPic(Uint32 armyset, Uint32 army, const Player* p,
-                                       int level, const bool *medals)
+                                       const bool *medals)
 {
     debug("getting army pic " <<armyset <<" " <<army <<" " <<p->getName())
 
@@ -424,7 +415,7 @@ SDL_Surface* GraphicsCache::getArmyPic(Uint32 armyset, Uint32 army, const Player
     for (it =d_armylist.begin(); it != d_armylist.end(); it++)
     {
         if (((*it)->armyset == armyset) && ((*it)->index == army)
-            && ((*it)->player ==p) && ((*it)->level==level) 
+            && ((*it)->player ==p)
             && ((*it)->medals[0]==my_medals[0])
             && ((*it)->medals[1]==my_medals[1])
             && ((*it)->medals[2]==my_medals[2]))
@@ -442,7 +433,7 @@ SDL_Surface* GraphicsCache::getArmyPic(Uint32 armyset, Uint32 army, const Player
     // We are still here, so the graphic is not in the cache. addArmyPic calls
     // checkPictures on its own, so we can simply return the surface
     debug("getarmypic============= " << my_medals) 
-    myitem = addArmyPic(armyset, army, p, level, my_medals);
+    myitem = addArmyPic(armyset, army, p, my_medals);
 
     return myitem->surface;
 }
@@ -474,6 +465,33 @@ SDL_Surface* GraphicsCache::getTemplePic(int type)
     return myitem->surface;
 }
 
+SDL_Surface* GraphicsCache::getRuinPic(int type)
+{
+    debug("GraphicsCache::getRuinPic " <<type)
+
+    std::list<RuinCacheItem*>::iterator it;
+    RuinCacheItem* myitem;
+
+    for (it = d_ruinlist.begin(); it != d_ruinlist.end(); it++)
+    {
+        if ((*it)->type == type)
+        {
+            myitem = (*it);
+
+            //put the item in last place (last touched)
+            d_ruinlist.erase(it);
+            d_ruinlist.push_back(myitem);
+
+            return myitem->surface;
+        }
+    }
+
+    //no item found -> create a new one
+    myitem = addRuinPic(type);
+
+    return myitem->surface;
+}
+
 SDL_Surface* GraphicsCache::getRoadPic(int type)
 {
     debug("GraphicsCache::getRoadPic " <<type)
@@ -582,34 +600,6 @@ SDL_Surface* GraphicsCache::getCursorPic(int type)
     return myitem->surface;
 }
 
-SDL_Surface* GraphicsCache::getStonePic(int type)
-{
-    debug("GraphicsCache::getStonePic " <<type)
-
-    std::list<StoneCacheItem*>::iterator it;
-    StoneCacheItem* myitem;
-
-    for (it = d_stonelist.begin(); it != d_stonelist.end(); it++)
-    {
-        if ((*it)->type == type)
-        {
-            myitem = (*it);
-
-            //put the item in last place (last touched)
-            d_stonelist.erase(it);
-            d_stonelist.push_back(myitem);
-
-            return myitem->surface;
-        }
-    }
-
-    //no item found -> create a new one
-    myitem = addStonePic(type);
-
-    return myitem->surface;
-}
-
-
 SDL_Surface* GraphicsCache::getCityPic(const City* city)
 {
     if (!city)
@@ -839,8 +829,8 @@ void GraphicsCache::checkPictures()
   while (d_templelist.size() > 10)
     eraseLastTempleItem();
 
-  while (d_stonelist.size() > 10)
-    eraseLastStoneItem();
+  while (d_ruinlist.size() > 10)
+    eraseLastRuinItem();
 
   while (d_roadlist.size() > 10)
     eraseLastRoadItem();
@@ -899,7 +889,8 @@ void GraphicsCache::checkPictures()
 }
 
 ArmyCacheItem* GraphicsCache::addArmyPic(Uint32 armyset, Uint32 army,
-					 const Player* p, int level, const bool *medalsbonus)
+					 const Player* p, 
+					 const bool *medalsbonus)
 {
   debug("ADD army pic: " <<armyset <<"," <<army)
 
@@ -907,7 +898,6 @@ ArmyCacheItem* GraphicsCache::addArmyPic(Uint32 armyset, Uint32 army,
   myitem->armyset = armyset;
   myitem->index = army;
   myitem->player = p;
-  myitem->level = level;
   myitem->medals[0] = medalsbonus[0];
   myitem->medals[1] = medalsbonus[1];
   myitem->medals[2] = medalsbonus[2];
@@ -919,38 +909,6 @@ ArmyCacheItem* GraphicsCache::addArmyPic(Uint32 armyset, Uint32 army,
   // copy the pixmap including player colors
   myitem->surface = applyMask(basearmy->getPixmap(), basearmy->getMask(), p);
 
-  if (level > 1 && d_levelmask)
-    {
-      SDL_Surface* mask = SDL_CreateRGBSurface(SDL_SWSURFACE, 40, 40,
-					       d_levelmask->format->BitsPerPixel,0,0,0,0);
-      // a little hack while waiting for a complete level picture
-      if (level<26) 
-	{
-	  SDL_Rect r;
-	  r.x = 40*(level-2);
-	  r.y = 0;
-	  r.w = r.h = 40;
-	  SDL_BlitSurface(d_levelmask, &r, mask, 0);
-	}
-      else 
-	{
-	  SDL_Rect r;
-	  r.x = 160;
-	  r.y = 0;
-	  r.w = r.h = 40;
-	  SDL_BlitSurface(d_levelmask, &r, mask, 0);
-	}
-
-      //set the first pixel as alpha value
-      SDL_SetColorKey(mask, SDL_SRCCOLORKEY, 0);
-
-      //blit mask over the army pic
-      SDL_BlitSurface(mask,0, myitem->surface, 0);
-
-      //free the temporary surface
-      SDL_FreeSurface(mask);
-    }
-
   if (d_medalsmask && medalsbonus != NULL)
     {
       debug("medalsbonus============= " << medalsbonus); 
@@ -999,14 +957,17 @@ ShipCacheItem* GraphicsCache::addShipPic(const Player* p)
 {
   debug("ADD ship pic: " <<p->getName())
 
-    ShipCacheItem* myitem = new ShipCacheItem();
+  ShipCacheItem* myitem = new ShipCacheItem();
   myitem->player = p;
 
   //Now the most important part: load the ship picture
   //First, copy the ship picture and change it to the display format
 
+  Armysetlist *al = Armysetlist::getInstance();
+  SDL_Surface *ship = al->getShipPic(p->getArmyset());
+  SDL_Surface *shipmask = al->getShipMask(p->getArmyset());
   // copy the pixmap including player colors
-  myitem->surface = applyMask(d_ship, d_shipmask, p);
+  myitem->surface = applyMask(ship, shipmask, p);
 
   //now the final preparation steps:
   //a) add the size
@@ -1033,8 +994,12 @@ PlantedStandardCacheItem* GraphicsCache::addPlantedStandardPic(const Player* p)
   //Now the most important part: load the planted standard picture
   //First, copy the picture and change it to the display format
 
+  Armysetlist *al = Armysetlist::getInstance();
+  SDL_Surface *standard = al->getStandardPic(p->getArmyset());
+  SDL_Surface *standard_mask = al->getStandardMask(p->getArmyset());
+
   // copy the pixmap including player colors
-  myitem->surface = applyMask(d_planted_standard, d_planted_standard_mask, p);
+  myitem->surface = applyMask(standard, standard_mask, p);
 
   //now the final preparation steps:
   //a) add the size
@@ -1075,6 +1040,27 @@ TempleCacheItem* GraphicsCache::addTemplePic(int type)
   return myitem;
 }
 
+RuinCacheItem* GraphicsCache::addRuinPic(int type)
+{
+  SDL_Surface* mysurf = SDL_DisplayFormatAlpha(d_ruinpic[type]);
+
+  //now create the cache item and add the size
+  RuinCacheItem* myitem = new RuinCacheItem();
+  myitem->type = type;
+  myitem->surface = mysurf;
+
+  d_ruinlist.push_back(myitem);
+
+  //add the size
+  int size = mysurf->w * mysurf->h;
+  d_cachesize += size * mysurf->format->BytesPerPixel;
+
+  //and check the size of the cache
+  checkPictures();
+
+  return myitem;
+}
+
 RoadCacheItem* GraphicsCache::addRoadPic(int type)
 {
   //    int ts = GameMap::getInstance()->getTileSet()->getTileSize();
@@ -1164,29 +1150,6 @@ CursorCacheItem* GraphicsCache::addCursorPic(int type)
   return myitem;
 }
 
-StoneCacheItem* GraphicsCache::addStonePic(int type)
-{
-  //    int ts = GameMap::getInstance()->getTileSet()->getTileSize();
-
-  SDL_Surface* mysurf = SDL_DisplayFormatAlpha(d_stonepic[type]);
-
-  //now create the cache item and add the size
-  StoneCacheItem* myitem = new StoneCacheItem();
-  myitem->type = type;
-  myitem->surface = mysurf;
-
-  d_stonelist.push_back(myitem);
-
-  //add the size
-  int size = mysurf->w * mysurf->h;
-  d_cachesize += size * mysurf->format->BytesPerPixel;
-
-  //and check the size of the cache
-  checkPictures();
-
-  return myitem;
-}
-
 CityCacheItem* GraphicsCache::addCityPic(int type, const Player* p)
 {
   //now create the cache item and add the size
@@ -1402,8 +1365,8 @@ void GraphicsCache::clear()
   while (!d_templelist.empty())
     eraseLastTempleItem();
 
-  while (!d_stonelist.empty())
-    eraseLastStoneItem();
+  while (!d_ruinlist.empty())
+    eraseLastRuinItem();
 
   while (!d_roadlist.empty())
     eraseLastRoadItem();
@@ -1479,6 +1442,21 @@ void GraphicsCache::eraseLastTempleItem()
   delete myitem;
 }
 
+void GraphicsCache::eraseLastRuinItem()
+{
+  if (d_ruinlist.empty())
+    return;
+
+  RuinCacheItem* myitem = *(d_ruinlist.begin());
+  d_ruinlist.erase(d_ruinlist.begin());
+
+  int size = myitem->surface->w * myitem->surface->h;
+  d_cachesize -= myitem->surface->format->BytesPerPixel * size;
+
+  SDL_FreeSurface(myitem->surface);
+  delete myitem;
+}
+
 void GraphicsCache::eraseLastRoadItem()
 {
   if (d_roadlist.empty())
@@ -1539,21 +1517,6 @@ void GraphicsCache::eraseLastCursorItem()
   delete myitem;
 }
 
-void GraphicsCache::eraseLastStoneItem()
-{
-  if (d_stonelist.empty())
-    return;
-
-  StoneCacheItem* myitem = *(d_stonelist.begin());
-  d_stonelist.erase(d_stonelist.begin());
-
-  int size = myitem->surface->w * myitem->surface->h;
-  d_cachesize -= myitem->surface->format->BytesPerPixel * size;
-
-  SDL_FreeSurface(myitem->surface);
-  delete myitem;
-}
-
 void GraphicsCache::eraseLastCityItem()
 {
   if (d_citylist.empty())
@@ -1692,7 +1655,7 @@ void GraphicsCache::eraseLastMoveBonusItem()
 void GraphicsCache::loadTemplePics()
 {
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
   int ts = GameMap::getInstance()->getTileSet()->getTileSize();
 
   // load the temple pictures
@@ -1708,13 +1671,14 @@ void GraphicsCache::loadTemplePics()
       SDL_PixelFormat* fmt = templepics->format;
 
       tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts, fmt->BitsPerPixel,
-				 fmt->Rmask, fmt->Gmask, fmt->Bmask, fmt->Amask);
+				 fmt->Rmask, fmt->Gmask, 
+				 fmt->Bmask, fmt->Amask);
 
       SDL_Rect r;
       r.x = i*ts;
       r.y = 0;
       r.w = r.h = ts;
-      SDL_BlitSurface(templepics, &r, tmp, 0);
+      SDL_BlitSurface(templepics, &r, tmp, NULL);
 
       d_templepic[i] = SDL_DisplayFormatAlpha(tmp);
 
@@ -1724,10 +1688,46 @@ void GraphicsCache::loadTemplePics()
   SDL_FreeSurface(templepics);
 }
 
+void GraphicsCache::loadRuinPics()
+{
+  // GameMap has the actual tileset stored
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
+  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+
+  // load the temple pictures
+  SDL_Surface* ruinpics = File::getMapsetPicture(tileset, "misc/ruin.png");
+
+  // copy alpha values, don't use them
+  SDL_SetAlpha(ruinpics, 0, 0);
+
+  for (unsigned int i = 0; i < RUIN_TYPES ; i++)
+    {
+      //copy the ruin image...
+      SDL_Surface* tmp;
+      SDL_PixelFormat* fmt = ruinpics->format;
+
+      tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts, fmt->BitsPerPixel,
+				 fmt->Rmask, fmt->Gmask, 
+				 fmt->Bmask, fmt->Amask);
+
+      SDL_Rect r;
+      r.x = i*ts;
+      r.y = 0;
+      r.w = r.h = ts;
+      SDL_BlitSurface(ruinpics, &r, tmp, NULL);
+
+      d_ruinpic[i] = SDL_DisplayFormatAlpha(tmp);
+
+      SDL_FreeSurface(tmp);
+    }
+
+  SDL_FreeSurface(ruinpics);
+}
+
 void GraphicsCache::loadRoadPics()
 {
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
   int ts = GameMap::getInstance()->getTileSet()->getTileSize();
 
   // load the road pictures
@@ -1763,9 +1763,10 @@ void GraphicsCache::loadFogPics()
 {
   // GameMap has the actual tileset stored
   int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
 
   // load the fog pictures
-  SDL_Surface* fogpics = File::getMiscPicture("fog.png");
+  SDL_Surface* fogpics = File::getMapsetPicture(tileset, "misc/fog.png");
 
   // copy alpha values, don't use them
   SDL_SetAlpha(fogpics, 0, 0);
@@ -1796,7 +1797,7 @@ void GraphicsCache::loadFogPics()
 void GraphicsCache::loadBridgePics()
 {
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
   int ts = GameMap::getInstance()->getTileSet()->getTileSize();
 
   // load the bridge pictures
@@ -1862,47 +1863,12 @@ void GraphicsCache::loadCursorPics()
   SDL_FreeSurface(cursorpics);
 }
 
-void GraphicsCache::loadStonePics()
-{
-  // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
-  int ts = GameMap::getInstance()->getTileSet()->getTileSize();
-
-  // load the stone pictures
-  SDL_Surface* stonepics = File::getMapsetPicture(tileset, "misc/stones.png");
-
-  // copy alpha values, don't use them
-  SDL_SetAlpha(stonepics, 0, 0);
-
-  for (unsigned int i = 0; i < STONE_TYPES ; i++)
-    {
-      //copy the stone image...
-      SDL_Surface* tmp;
-      SDL_PixelFormat* fmt = stonepics->format;
-
-      tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, ts, ts, fmt->BitsPerPixel,
-				 fmt->Rmask, fmt->Gmask, fmt->Bmask, fmt->Amask);
-
-      SDL_Rect r;
-      r.x = i*ts;
-      r.y = 0;
-      r.w = r.h = ts;
-      SDL_BlitSurface(stonepics, &r, tmp, 0);
-
-      d_stonepic[i] = SDL_DisplayFormatAlpha(tmp);
-
-      SDL_FreeSurface(tmp);
-    }
-
-  SDL_FreeSurface(stonepics);
-}
-
 void GraphicsCache::loadCityPics()
 {
   SDL_Surface *tmp;
   SDL_PixelFormat *fmt;
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
   int size = GameMap::getInstance()->getTileSet()->getTileSize() * 2;
 
   // load the image for the razed city
@@ -1973,7 +1939,7 @@ void GraphicsCache::loadTowerPics()
   SDL_Surface *tmp;
   SDL_PixelFormat *fmt;
   // GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
   int size = GameMap::getInstance()->getTileSet()->getTileSize();
 
   // load the image for the towers
@@ -2004,73 +1970,14 @@ void GraphicsCache::loadTowerPics()
 
 }
 
-void GraphicsCache::loadShipPic()
-{
-  //load the ship picture and it's mask
-  SDL_Rect shiprect;
-  SDL_Surface* shippic = File::getMiscPicture("stackship.png");
-  // copy alpha values, don't use them
-  SDL_SetAlpha(shippic, 0, 0);
-  SDL_PixelFormat* fmt = shippic->format;
-  int size = 54;
-  SDL_Surface* tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, size, size, 
-					  fmt->BitsPerPixel, fmt->Rmask, 
-					  fmt->Gmask, fmt->Bmask, 
-					  fmt->Amask);
-  shiprect.x = 0;
-  shiprect.y = 0;
-  shiprect.w = shiprect.h = size;
-  SDL_BlitSurface(shippic, &shiprect, tmp, 0);
-  d_ship = SDL_DisplayFormatAlpha(tmp);
-  SDL_FreeSurface(tmp);
-
-  d_shipmask =  SDL_CreateRGBSurface(SDL_SWSURFACE, size, size, 32,
-				     0xFF000000, 0xFF0000, 0xFF00, 
-				     0xFF);
-  shiprect.x = size;
-  shiprect.y = 0;
-  shiprect.w = shiprect.h = size;
-  SDL_BlitSurface(shippic, &shiprect, d_shipmask, 0);
-
-  SDL_FreeSurface(shippic);
-}
-
-void GraphicsCache::loadPlantedStandardPic()
-{
-  //load the planted standard picture and it's mask
-  SDL_Rect psrect;
-  SDL_Surface* pspic = File::getMiscPicture("plantedstandard.png");
-  // copy alpha values, don't use them
-  SDL_SetAlpha(pspic, 0, 0);
-  SDL_PixelFormat* fmt = pspic->format;
-  int size = 54;
-  SDL_Surface* tmp = SDL_CreateRGBSurface(SDL_SWSURFACE, size, size, 
-					  fmt->BitsPerPixel, fmt->Rmask, 
-					  fmt->Gmask, fmt->Bmask, 
-					  fmt->Amask);
-  psrect.x = 0;
-  psrect.y = 0;
-  psrect.w = psrect.h = size;
-  SDL_BlitSurface(pspic, &psrect, tmp, 0);
-  d_planted_standard = SDL_DisplayFormatAlpha(tmp);
-  SDL_FreeSurface(tmp);
-
-  d_planted_standard_mask = SDL_CreateRGBSurface(SDL_SWSURFACE, size, size, 
-						 32, 0xFF000000, 0xFF0000, 
-						 0xFF00, 0xFF);
-  psrect.x = size;
-  psrect.y = 0;
-  psrect.w = psrect.h = size;
-  SDL_BlitSurface(pspic, &psrect, d_planted_standard_mask, 0);
-
-  SDL_FreeSurface(pspic);
-}
-
 void GraphicsCache::loadSelectors()
 {
   //load the big selector pictures
   int i;
-  SDL_Surface* selpics = File::getMiscPicture("selector.png");
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
+
+  // to build flags, we need these three images as basic blocks
+  SDL_Surface* selpics = File::getMapsetPicture(tileset, "misc/selector.png");
   SDL_PixelFormat* fmt = selpics->format;
   int size = GameMap::getInstance()->getTileSet()->getTileSize();
 
@@ -2100,7 +2007,7 @@ void GraphicsCache::loadSelectors()
   SDL_FreeSurface(selpics);
 
   //load the small selector pictures
-  selpics = File::getMiscPicture("small_selector.png");
+  selpics = File::getMapsetPicture(tileset, "misc/small_selector.png");
   fmt = selpics->format;
   // copy alpha values, don't use them
   SDL_SetAlpha(selpics, 0, 0);
@@ -2290,7 +2197,7 @@ void GraphicsCache::loadMoveBonusPics()
 void GraphicsCache::loadFlags()
 {
   //GameMap has the actual tileset stored
-  std::string tileset = GameMap::getInstance()->getTileSet()->getName();
+  std::string tileset = GameMap::getInstance()->getTileSet()->getSubDir();
 
   // to build flags, we need these three images as basic blocks
   SDL_Surface* flag = File::getMapsetPicture(tileset, "misc/flags.png");
