@@ -61,7 +61,7 @@ MapGenerator::MapGenerator()
     //set reasonable default values
     :d_terrain(0), d_building(0), d_l_mass(0), d_pswamp(2), d_pwater(25), d_pforest(3),
     d_phills(5), d_pmountains(5), d_nocities(11), d_notemples(9), d_noruins(20),
-    d_nosignposts(30), d_nostones(30)
+    d_nosignposts(30)
 
 {
     d_xdir[0]=0;d_xdir[1]=-1;d_xdir[2]=-1;d_xdir[3]=-1;d_xdir[4]=0;d_xdir[5]=1;d_xdir[6]=1;d_xdir[7]=1;
@@ -108,16 +108,6 @@ int MapGenerator::setNoSignposts(int nosignposts)
     return tmp;
 }
 
-int MapGenerator::setNoStones (int nostones)
-{
-    if (nostones < 0)
-        return -1;
-
-    int tmp = d_nostones;
-    d_nostones = nostones;
-    return tmp;
-}
-
 int MapGenerator::setNoTemples(int notemples)
 {
     if (notemples < 0)
@@ -181,7 +171,7 @@ void MapGenerator::makeMap(int width, int height)
     makePlains();
     cout <<_("Raining Water     ... 30%") <<endl;
     makeTerrain(Tile::WATER, d_pwater, true);  
-    makeStreamer(Tile::WATER, d_pwater/3, 2);
+    makeStreamer(Tile::WATER, d_pwater/3, 3);
     cout <<_("Raising Hills     ... 20%") <<endl;
     makeTerrain(Tile::HILLS, d_phills, false);
     cout <<_("Raising Mountains ... 30%") <<endl;
@@ -206,8 +196,6 @@ void MapGenerator::makeMap(int width, int height)
     makeBuildings(Maptile::RUIN,d_noruins);
     cout <<_("Raising Signs     ... 88%") <<endl;
     makeBuildings(Maptile::SIGNPOST,d_nosignposts);
-    cout <<_("Placing Stones    ... 89%") <<endl;
-    makeBuildings(Maptile::STONE,d_nostones);
     cout <<_("Spawning temples  ... 90%") <<endl;
     makeBuildings(Maptile::TEMPLE,d_notemples);
     cout <<_("Done making map   ... 100%") <<endl;
@@ -620,8 +608,7 @@ void MapGenerator::makeBuildings(Maptile::Building b, int building)
 bool MapGenerator::canPutBuilding(int x,int y)
 {
     // if the building is on water or mountains, return false
-    if (d_terrain[y*d_width +x] == Tile::WATER ||
-        d_terrain[y*d_width +x] == Tile::MOUNTAIN)
+    if (d_terrain[y*d_width +x] != Tile::GRASS )
         return false;
         
     //if the building is close to the map boundaries, return false
@@ -914,7 +901,7 @@ bool MapGenerator::walkCoastAntiClock(int& x,int& y, int sea_id, int dist, int&
 }
 
 void MapGenerator::normalize()
-{   
+{
     std::map<Uint32,Uint32> ajacentTer;
     Tile::Type curTer=Tile::NONE, ajTer=Tile::NONE;
     
@@ -966,7 +953,6 @@ void MapGenerator::normalize()
         }
 }
 
-
 void MapGenerator::continents(int& nmrLands, int& nmrSeas)
 {   
     int l_id = 0;   // id of the current continent to set
