@@ -26,6 +26,7 @@
 #include "AI_Allocation.h"
 #include "action.h"
 #include "xmlhelper.h"
+#include "history.h"
 
 using namespace std;
 
@@ -56,7 +57,7 @@ AI_Smart::~AI_Smart()
 bool AI_Smart::startTurn()
 {
     debug(getName() << " start_turn")
-    clearActionlist();
+    RealPlayer::startTurn();
 
     // the real stuff
     examineCities();
@@ -102,6 +103,10 @@ bool AI_Smart::invadeCity(City* c)
 bool AI_Smart::recruitHero(Hero* hero, City *city, int cost)
 {
     debug("AI_Smart: hero recruited")
+    History_HeroEmerges *item = new History_HeroEmerges();
+    item->fillData(hero, city);
+    d_history.push_back(item);
+
     return true;    //always recruit heroes
 }
 
