@@ -58,7 +58,15 @@ Army::Army(const Army& a, Player* p)
     }  
 }
 
-Army::Army(XML_Helper* helper, bool prototype)
+Army::Army()
+  :d_pixmap(0), d_mask(0), d_name("Untitled"), d_description(""),
+    d_production(0), d_production_cost(0), d_upkeep(0), d_strength(0),
+    d_max_hp(0), d_max_moves(0), d_sight(0), d_gender(NONE), d_level(1), 
+   d_defends_ruins(false), d_awardable(false), d_hero(false), d_image("")
+{
+}
+
+Army::Army(XML_Helper* helper, enum ArmyContents contents)
   :d_pixmap(0), d_mask(0), d_name(""), d_description(""), d_ship(false),
    d_gender(NONE), d_player(0), 
    d_id(0), d_xp(0), d_level(1), d_grouped(true),
@@ -75,7 +83,7 @@ Army::Army(XML_Helper* helper, bool prototype)
     
     // now if we are a prototype, we have to load different data than
     // otherwise
-    if (!prototype)
+    if (contents == INSTANCE)
     {
         int ival = -1;
         //get the information which army we are
@@ -117,9 +125,10 @@ Army::Army(XML_Helper* helper, bool prototype)
         if (ival != -1)
           d_visitedTemples.push_front(ival);
     }
-    else
+    else if (contents == TYPE || contents == PRODUCTION_BASE)
     {
         helper->getData(d_name, "name");
+        helper->getData(d_image, "image");
         helper->getData(d_description, "description");
         helper->getData(d_production, "production");
         helper->getData(d_production_cost, "production_cost");
@@ -142,6 +151,11 @@ Army::Army(XML_Helper* helper, bool prototype)
             d_medal_bonus[i] = false;
       helper->getData(d_hero,"hero");
     }
+    if (contents == PRODUCTION_BASE)
+      {
+	helper->getData(d_type, "type");
+	helper->getData(d_armyset, "armyset");
+      }
 }
 
 Army::~Army()
@@ -195,7 +209,7 @@ SDL_Surface* Army::getPixmap() const
     
     //use the GraphicsCache to get a picture of the army's armyset_army
     return GraphicsCache::getInstance()->getArmyPic(d_armyset, d_type,
-                                         d_player, d_level, d_medal_bonus);
+                                         d_player, d_medal_bonus);
 }
 
 Uint32 Army::getStat(Stat stat, bool modified) const
@@ -368,35 +382,62 @@ int Army::gainLevel(Stat stat)
 }
 
 
-bool Army::save(XML_Helper* helper) const
+bool Army::save(XML_Helper* helper, enum ArmyContents contents) const
 {
     bool retval = true;
 
     retval &= helper->openTag("army");
-    retval &= saveData(helper);
+    retval &= saveData(helper, contents);
     retval &= helper->closeTag();
 
     return retval;
 }
 
-bool Army::saveData(XML_Helper* helper) const
+bool Army::saveData(XML_Helper* helper, enum ArmyContents contents) const
 {
     bool retval = true;
     
-    retval &= helper->saveData("id", d_id);
-    retval &= helper->saveData("armyset", d_armyset);
-    retval &= helper->saveData("type", d_type);
+    if (contents == TYPE || contents == PRODUCTION_BASE)
+      {
+	retval &= helper->saveData("name", d_name);
+	retval &= helper->saveData("description", d_description);
+	retval &= helper->saveData("image", d_image);
+	retval &= helper->saveData("production", d_production);
+	retval &= helper->saveData("production_cost", d_production_cost);
+	retval &= helper->saveData("upkeep", d_upkeep);
+	retval &= helper->saveData("gender", d_gender);
+	retval &= helper->saveData("awardable", d_awardable);
+	retval &= helper->saveData("defends_ruins", d_defends_ruins);
+	retval &= helper->saveData("move_bonus", d_move_bonus);
+	retval &= helper->saveData("army_bonus", d_army_bonus);
+      }
+    else if (contents == INSTANCE)
+      {
+	retval &= helper->saveData("id", d_id);
+	retval &= helper->saveData("armyset", d_armyset);
+	retval &= helper->saveData("type", d_type);
+	retval &= helper->saveData("hp", d_hp);
+	retval &= helper->saveData("ship", d_ship);
+	retval &= helper->saveData("moves", d_moves);
+	retval &= helper->saveData("xp", d_xp);
+      }
+
+    if (contents == PRODUCTION_BASE)
+      {
+	retval &= helper->saveData("type", d_type);
+	retval &= helper->saveData("armyset", d_armyset);
+      }
+
+    retval &= helper->saveData("max_moves", d_max_moves);
     retval &= helper->saveData("hero", d_hero);
-    retval &= helper->saveData("hp", d_hp);
     retval &= helper->saveData("strength", d_strength);
     retval &= helper->saveData("sight", d_sight);
-    retval &= helper->saveData("moves", d_moves);
-    retval &= helper->saveData("ship", d_ship);
-    retval &= helper->saveData("max_moves", d_max_moves);
-    retval &= helper->saveData("xp", d_xp);
     retval &= helper->saveData("expvalue", getXpReward());
     retval &= helper->saveData("level", d_level);
 
+    if (contents == PRODUCTION_BASE || contents == TYPE)
+      return retval;
+
     std::stringstream medals;
     for (int i=0;i<3;i++)
     {
@@ -492,3 +533,16 @@ bool Army::getFortified ()
   return (d_army_bonus & Army::FORTIFY) == Army::FORTIFY;
 }
 
+void Army::setPixmap(SDL_Surface* pixmap)
+{
+  if (d_pixmap)
+    SDL_FreeSurface(d_pixmap);
+  d_pixmap = pixmap;
+}
+        
+void Army::setMask(SDL_Surface* mask)
+{
+  if (d_mask)
+    SDL_FreeSurface(d_mask);
+  d_mask = mask;
+}
