@@ -31,12 +31,17 @@ class XML_Helper;
   * This class is the atom of every army. It contains all data related to
   * a single army type of an armyset, such as strength, defense, movement points
   * and so on.
+  *
+  * type is what is in the xml file
+  * production base is what a city has to make other armies from
+  * instance is what moves around the map
   */
 
 class Army : public sigc::trackable
 {
     public:
 
+	enum ArmyContents {TYPE = 0, PRODUCTION_BASE = 1, INSTANCE = 2};
         //! used only for heroes (e.g. to decide about the recruitment image)
         enum Gender {NONE = 0, MALE = 1, FEMALE = 2};
 
@@ -89,8 +94,12 @@ class Army : public sigc::trackable
           * @param prototype    if set to false, load some additional values
           *                     instead of setting defaults (e.g. id, level)
           */
-        Army(XML_Helper* helper, bool prototype = false);
+        Army(XML_Helper* helper, enum ArmyContents contents = INSTANCE);
         
+	/**  creates a new prototype army
+	 */
+	Army();
+
         virtual ~Army();
 
 
@@ -106,10 +115,10 @@ class Army : public sigc::trackable
         void setName(std::string name){d_name = name;}
 
         //! Set the basic image of the unit type
-        void setPixmap(SDL_Surface* pixmap){d_pixmap = pixmap;}
+        void setPixmap(SDL_Surface* pixmap);
 
         //! Set the mask of the unit type (for player colors)
-        void setMask(SDL_Surface* mask){d_mask = mask;}
+        void setMask(SDL_Surface* mask);
 
         //! Set how much XP this unit is worth when killed
         void setXpReward(double xp_value){d_xp_value = xp_value;}
@@ -168,6 +177,10 @@ class Army : public sigc::trackable
         //! Returns the mask (read-only!!) for player colors
         SDL_Surface* getMask() const {return d_mask;}
 
+	//! Returns the basename of the picture's filename
+	std::string getImageName() const {return d_image;}
+	void setImageName(std::string image) {d_image = image;}
+
         //! Returns the descriptive text of this army
         std::string getDescription() const {return d_description;}
 
@@ -218,6 +231,7 @@ class Army : public sigc::trackable
 
         //! Returns whether the army is a hero
         bool isHero() const {return d_hero;}
+	void setHero(bool hero) {d_hero = hero;}
 
         /** Heal the unit
           * 
@@ -292,7 +306,7 @@ class Army : public sigc::trackable
         void printAllDebugInfo() const;
 
         //! Saves the unit information (see XML_Helper for further info)
-        virtual bool save(XML_Helper* helper) const;
+        virtual bool save(XML_Helper* helper, enum ArmyContents contents = INSTANCE) const;
         
         //! This signal is raised when the army dies; it is static because
         //! sometimes the army doesn't exist yet when the signal is connected
@@ -325,7 +339,7 @@ class Army : public sigc::trackable
     protected:
         //! Generic function for saving the army data. Useful for the hero class,
         //  which doesn't need to repeat the save code.
-        bool saveData(XML_Helper* helper) const;
+        bool saveData(XML_Helper* helper, enum ArmyContents contents = INSTANCE) const;
 
         //! Copies the generic data from the original prototype army (used for loading)
         void copyVals(const Army* a);
@@ -386,6 +400,8 @@ class Army : public sigc::trackable
 
 	//!how many xp points per level?
         static const int xp_per_level = 10;
+
+	std::string d_image;
 };
 
 #endif // ARMY_H
