@@ -28,14 +28,13 @@
 #include "ruinlist.h"
 #include "signpostlist.h"
 #include "templelist.h"
-#include "stonelist.h"
+#include "armysetlist.h"
 #include "portlist.h"
 #include "bridgelist.h"
 #include "roadlist.h"
 #include "ruin.h"
 #include "signpost.h"
 #include "temple.h"
-#include "stone.h"
 #include "road.h"
 #include "playerlist.h"
 #include "defs.h"
@@ -57,7 +56,6 @@ BigMap::BigMap()
     : d_renderer(0), buffer(0)
 {
     // load all pictures
-    d_ruinpic = File::getMapsetPicture("default", "misc/ruin.png");
     d_signpostpic = File::getMapsetPicture("default", "misc/signpost.png");
 
 
@@ -69,7 +67,6 @@ BigMap::BigMap()
 
 BigMap::~BigMap()
 {
-    SDL_FreeSurface(d_ruinpic);
     SDL_FreeSurface(d_signpostpic);
     SDL_FreeSurface(d_itempic);
 
@@ -158,20 +155,6 @@ void BigMap::draw(bool redraw_buffer)
     SDL_UpdateRects(screen, 1, &dest);
 }
 
-void BigMap::center_view(const Vector<int> p)
-{
-    if (Playerlist::getActiveplayer()->getType() != Player::HUMAN &&
-        GameScenario::s_hidden_map == true)
-        return;
-
-    Rectangle new_view(
-	clip(Vector<int>(0,0), p - view.dim / 2, GameMap::get_dim() - view.dim),
-	view.dim);
-    
-    set_view(new_view);
-    view_changed.emit(view);
-}
-
 void BigMap::screen_size_changed()
 {
     SDL_Surface *v = SDL_GetVideoSurface();
@@ -493,11 +476,14 @@ void BigMap::draw_stack(Stack *s)
   int tilesize = GameMap::getInstance()->getTileSet()->getTileSize();
   Vector<int> p = s->getPos();
   Player *player = s->getPlayer();
+  int army_tilesize;
 
   // check if the object lies in the viewed part of the map
   // otherwise we shouldn't draw it
   if (is_inside(buffer_view, p) && !s->getDeleting())
     {
+      Armysetlist *al = Armysetlist::getInstance();
+      army_tilesize = al->getTileSize(player->getArmyset());
       if (s->empty())
 	{
 	  std::cerr << "WARNING: empty stack found" << std::endl;
@@ -509,17 +495,20 @@ void BigMap::draw_stack(Stack *s)
       // draw stack
 		
       SDL_Rect r;
-      r.x = p.x + 6;
-      r.y = p.y + 6;
-      r.w = r.h = 54;
+      r.x = p.x;
+      r.y = p.y;
 
       bool show_army = true;
       if (s->hasShip())
-	SDL_BlitSurface(gc->getShipPic(player), 0, buffer, &r);
+	{
+	  r.w = r.h = army_tilesize;
+	  SDL_BlitSurface(gc->getShipPic(player), 0, buffer, &r);
+	}
       else
 	{
 	  if (s->getFortified() == true)
 	    {
+	      r.w = r.h = tilesize;
 	      if (player->getStacklist()->getActivestack() != s &&
 		  player == Playerlist::getActiveplayer())
 		show_army = false;
@@ -534,6 +523,7 @@ void BigMap::draw_stack(Stack *s)
 		      
 	  if (show_army == true)
 	    {
+	      r.w = r.h = army_tilesize;
 	      Army *a = *s->begin();
 	      SDL_BlitSurface(a->getPixmap(), 0, buffer, &r);
 	    }
@@ -564,7 +554,7 @@ void BigMap::draw_buffer()
         if (((*i).isHidden() == true && 
                (*i).getOwner() == Playerlist::getActiveplayer()) ||
              (*i).isHidden() == false)
-	  blit_if_inside_buffer(*i, d_ruinpic);
+	  blit_if_inside_buffer(*i, gc->getRuinPic((*i).getType()));
       }
 
     for (Signpostlist::iterator i = Signpostlist::getInstance()->begin();
@@ -579,10 +569,6 @@ void BigMap::draw_buffer()
 	 i != Roadlist::getInstance()->end(); ++i)
 	blit_if_inside_buffer( *i, gc->getRoadPic(i->getType()));
 
-    for (Stonelist::iterator i = Stonelist::getInstance()->begin();
-	 i != Stonelist::getInstance()->end(); ++i)
-	blit_if_inside_buffer( *i, gc->getStonePic(i->getType()));
-
     for (Bridgelist::iterator i = Bridgelist::getInstance()->begin();
 	 i != Bridgelist::getInstance()->end(); ++i)
 	blit_if_inside_buffer( *i, gc->getBridgePic(i->getType()));
@@ -620,12 +606,15 @@ void BigMap::draw_buffer()
 		Vector<int> p = tile_to_buffer_pos(Vector<int>(x, y));
                 if (standard_planted && flag)
                 {
+		    Armysetlist *al = Armysetlist::getInstance();
+		    Player *player = flag->getPlantableOwner();
+		    int army_tilesize = al->getTileSize(player->getArmyset());
 		    SDL_Rect r;
-		    r.x = p.x+(tilesize-54);
-		    r.y = p.y+(tilesize-54);
-		    r.w = r.h = 54;
+		    r.x = p.x+((tilesize/2)-(army_tilesize/2));
+		    r.y = p.y+((tilesize/2)-(army_tilesize/2));
+		    r.w = r.h = army_tilesize;
                     SDL_Surface *surf;
-                    surf = gc->getPlantedStandardPic(flag->getPlantableOwner());
+                    surf = gc->getPlantedStandardPic(player);
 		    SDL_BlitSurface(surf, 0, buffer,&r);
                 }
                 else
