@@ -53,7 +53,6 @@ class BigMap: public sigc::trackable
 
     // view the rectangle, measured in tiles
     void set_view(Rectangle rect);
-    void center_view(Vector<int> p);
     void screen_size_changed();
 
     // return a good position of a map tip given that it should be close to the
@@ -74,7 +73,6 @@ class BigMap: public sigc::trackable
 	
     bool input_locked;
 	
-    SDL_Surface* d_ruinpic;
     SDL_Surface* d_signpostpic;
     SDL_Surface* d_itempic;
         
