@@ -101,10 +101,10 @@ class City : public Location
           * @param index        the index of the production slot; if set to -1,
           *                     the city will try to find a free production slot
           *                     and overwrite an existing one if neccessary.
-          * @param armytype     the index of the army within the armyset
+	  * @param army         the army to add
           * @return true on success, false on error
           */
-        bool addBasicProd(int index, int armytype);
+        bool addBasicProd(int index, Army *army);
 
         //! Clears the basic production of a given slot
         void removeBasicProd(int index);
@@ -113,7 +113,7 @@ class City : public Location
         void conquer(Player* newowner);
         
         //! Sets the production to random starting values
-        void setRandomArmytypes();
+        void setRandomArmytypes(bool produce_allies);
 
         //! Produces the strongest army the city can produce
         void produceStrongestArmy();
@@ -121,6 +121,11 @@ class City : public Location
         //! Produces the weakest army the city can produce
         void produceWeakestArmy();
 
+        //! Produces a weak army for exploring (used when neutral cities are
+	// "average".  The scout army doesn't have to be a buildable army
+	// by the city for this method to operate.
+        void produceScout();
+
         //! Do everything neccessary for a new turn
         void nextTurn();
 
@@ -190,11 +195,13 @@ class City : public Location
         //! Produces the currently selected army
         Army * produceArmy();
 
+	void randomlyImproveOrDegradeArmy(Army *army);
 
         // DATA
         Player* d_player;           // Owner
         
-        int d_basicprod[4];         // possible basic productions
+        Army* d_basicprod[4];         // possible basic productions
+	//std::vector<Army*> d_basicprod;
         int d_numbasic;             // max number of possible basic productions
 
         int d_production;           // number of produced armytype
