@@ -27,14 +27,12 @@
 #include "../ruinlist.h"
 #include "../signpostlist.h"
 #include "../templelist.h"
-#include "../stonelist.h"
 #include "../bridgelist.h"
 #include "../portlist.h"
 #include "../roadlist.h"
 #include "../ruin.h"
 #include "../signpost.h"
 #include "../temple.h"
-#include "../stone.h"
 #include "../road.h"
 #include "../playerlist.h"
 #include "../defs.h"
@@ -56,23 +54,27 @@ EditorBigMap::EditorBigMap()
     pointer = EditorBigMap::POINTER;
     pointer_size = 1;
     pointer_terrain = Tile::GRASS;
+    pointer_tile_style_id = -1;
 }
 
 EditorBigMap::~EditorBigMap()
 {
 }
 
-void EditorBigMap::set_pointer(Pointer p, int size, Tile::Type t)
+void EditorBigMap::set_pointer(Pointer p, int size, Tile::Type t, 
+			       int tile_style_id)
 {
     bool redraw = false;
-    if (pointer != p || pointer_size != size)
-	redraw = true;
+    if (pointer != p || pointer_size != size || 
+	pointer_tile_style_id != tile_style_id)
+      redraw = true;
     pointer = p;
     pointer_terrain = t;
     pointer_size = size;
+    pointer_tile_style_id = tile_style_id;
 
     if (redraw)
-	draw();
+      draw();
 }
 
 void EditorBigMap::mouse_button_event(MouseButtonEvent e)
@@ -125,11 +127,6 @@ void EditorBigMap::mouse_motion_event(MouseMotionEvent e)
 	redraw = true;
     }
 
-    if (mouse_pos != prev_mouse_pos && pointer == STONE &&
-	mouse_pos_to_stone_type(mouse_pos) !=
-	mouse_pos_to_stone_type(prev_mouse_pos))
-	redraw = true;
-
     // draw with left mouse button
     if (e.pressed[MouseMotionEvent::LEFT_BUTTON])
     {
@@ -255,7 +252,7 @@ void EditorBigMap::after_draw()
 	case STACK:
 	    pic = GraphicsCache::getInstance()->getArmyPic(
 		Playerlist::getInstance()->getNeutral()->getArmyset(), 0,
-		Playerlist::getInstance()->getNeutral(), 1, NULL);
+		Playerlist::getInstance()->getNeutral(), NULL);
 	    SDL_BlitSurface(pic, 0, buffer, &r);
 	    break;
 	    
@@ -267,7 +264,7 @@ void EditorBigMap::after_draw()
 	    break;
 	    
 	case RUIN:
-	    pic = d_ruinpic;
+	    pic = GraphicsCache::getInstance()->getRuinPic(0);
 	    SDL_BlitSurface(pic, 0, buffer, &r);
 	    break;
 	    
@@ -281,15 +278,6 @@ void EditorBigMap::after_draw()
 	    SDL_BlitSurface(pic, 0, buffer, &r);
 	    break;
 	    
-	case STONE:
-	    pic = GraphicsCache::getInstance()->getStonePic(
-		mouse_pos_to_stone_type(mouse_pos));
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    draw_rect_clipped(buffer, pos.x + 1, pos.y + 1,
-			      pos.x + tilesize - 2, pos.y + tilesize - 2,
-			      outline);
-	    break;
-	    
 	case ROAD:
 	    pic = GraphicsCache::getInstance()->getRoadPic(tile_to_road_type(*i));
 	    SDL_BlitSurface(pic, 0, buffer, &r);
@@ -306,41 +294,6 @@ void EditorBigMap::after_draw()
     }
 }
 
-int EditorBigMap::mouse_pos_to_stone_type(Vector<int> mpos)
-{
-    Vector<int> p = mouse_pos_to_tile_offset(mpos);
-    int type = 0;
-    if (p.x > 43)
-    {
-	if (p.y > 43)
-	    type = 5;
-	else if (p.y > 21)
-	    type = 3;
-	else
-	    type = 2;
-    }
-    else if (p.x > 21)
-    {
-	if (p.y > 43)
-	    type = 6;
-	else if (p.y > 21)
-	    type = 4;
-	else
-	    type = 1;
-    }
-    else
-    {
-	if (p.y > 43)
-	    type = 7; 
-	else if (p.y > 21)
-	    type = 8;
-	else
-	    type = 0;
-    }
-    
-    return type;
-}
-
 int EditorBigMap::tile_to_bridge_type(Vector<int> t)
 {
     // examine neighbour tiles to discover whether there's a road on them
@@ -350,7 +303,7 @@ int EditorBigMap::tile_to_bridge_type(Vector<int> t)
     bool r = Roadlist::getInstance()->getObjectAt(t + Vector<int>(1, 0));
 
     // then translate this to the type
-    int type = 7;
+    int type = 0;
     if (!u && !b && !l && !r)
 	type = 0;
     else if (u && b && l && r)
@@ -370,19 +323,19 @@ int EditorBigMap::tile_to_bridge_type(Vector<int> t)
     else if (u && !b && l && !r)
 	type = 0;
     else if (u && !b && !l && r)
-	type = 0;
+	type = 2;
     else if (!u && b && l && !r)
 	type = 0;
     else if (!u && b && !l && r)
-	type = 1;
+	type = 2;
     else if (u && !b && !l && !r)
-	type = 1;
+	type = 3;
     else if (!u && b && !l && !r)
 	type = 1;
     else if (!u && !b && l && !r)
 	type = 0;
     else if (!u && !b && !l && r)
-	type = 0;
+	type = 2;
     return type;
 }
 
@@ -390,25 +343,35 @@ int EditorBigMap::tile_to_bridge_type(Vector<int> t)
 int EditorBigMap::tile_to_road_type(Vector<int> t)
 {
     // examine neighbour tiles to discover whether there's a road on them
-    bool u = Roadlist::getInstance()->getObjectAt(t + Vector<int>(0, -1));
-    bool b = Roadlist::getInstance()->getObjectAt(t + Vector<int>(0, 1));
-    bool l = Roadlist::getInstance()->getObjectAt(t + Vector<int>(-1, 0));
-    bool r = Roadlist::getInstance()->getObjectAt(t + Vector<int>(1, 0));
+    bool u = false; //up
+    bool b = false; //bottom
+    bool l = false; //left
+    bool r = false; //right
+
+    if (t.y > 0)
+      u = Roadlist::getInstance()->getObjectAt(t + Vector<int>(0, -1));
+    if (t.y < GameMap::getHeight() - 1)
+      b = Roadlist::getInstance()->getObjectAt(t + Vector<int>(0, 1));
+    if (t.x > 0)
+      l = Roadlist::getInstance()->getObjectAt(t + Vector<int>(-1, 0));
+    if (t.x < GameMap::getWidth() - 1)
+    r = Roadlist::getInstance()->getObjectAt(t + Vector<int>(1, 0));
 
     // then translate this to the type
-    int type = 7;
+    int type = 2; 
+    //show road type 2 when no other road tiles are around
     if (!u && !b && !l && !r)
-	type = 7;
+	type = 2;
     else if (u && b && l && r)
 	type = 2;
     else if (!u && b && l && r)
-	type = 10;
-    else if (u && !b && l && r)
 	type = 9;
-    else if (u && b && !l && r)
+    else if (u && !b && l && r)
 	type = 8;
+    else if (u && b && !l && r)
+	type = 7;
     else if (u && b && l && !r)
-	type = 11;
+	type = 10;
     else if (u && b && !l && !r)
 	type = 1;
     else if (!u && !b && l && r)
@@ -460,6 +423,12 @@ void EditorBigMap::change_map_under_cursor()
     std::vector<Vector<int> > tiles = get_cursor_tiles();
     TileSet* ts = GameMap::getInstance()->getTileSet();
     
+    // find the index of the "grass" tile
+    unsigned int grass_index;
+    for (grass_index = 0; grass_index < ts->size(); ++grass_index)
+      if ((*ts)[grass_index]->getType() == Tile::GRASS)
+	break;
+        
     for (std::vector<Vector<int> >::iterator i = tiles.begin(),
 	     end = tiles.end(); i != end; ++i)
     {
@@ -483,15 +452,24 @@ void EditorBigMap::change_map_under_cursor()
 		&& pointer_terrain != Tile::GRASS)
 		break;
 
-	    if (pointer_terrain == maptile->getMaptileType())
-		break;
+	    if (pointer_terrain == maptile->getMaptileType() &&
+		pointer_tile_style_id == -1)
+	      break;
 
 	    maptile->setType(ts->getIndex(pointer_terrain));
-
-	    // we expect the renderer to catch out of bound errors
-	    for (int x = tile.x - 1; x <= tile.x + 1; ++x)
-		for (int y = tile.y - 1; y <= tile.y + 1; ++y)
-		    d_renderer->smooth(x, y);
+	    if (pointer_tile_style_id == -1)
+	      {
+		GameMap::getInstance()->applyTileStyles(tile.y-1, tile.x-1, 
+							tile.y+2, tile.x+2,
+							false);
+	      }
+	    else
+	      {
+		TileSet *tileset = GameMap::getInstance()->getTileSet();
+		TileStyle *tile_style;
+		tile_style = tileset->getTileStyle(pointer_tile_style_id);
+		maptile->setTileStyle (tile_style);
+	      }
 	    changed_tiles.dim = Vector<int>(1, 1);
 	    break;
 	    
@@ -509,8 +487,6 @@ void EditorBigMap::change_map_under_cursor()
 	    
 	    // ... or a temple ...
 	    remove_from_map(Templelist::getInstance(), tile);
-	    // ... or a stone ...
-	    remove_from_map(Stonelist::getInstance(), tile);
 	    // ... or a port ...
 	    remove_from_map(Portlist::getInstance(), tile);
 	    // ... or a ruin ...
@@ -537,6 +513,27 @@ void EditorBigMap::change_map_under_cursor()
 		Army* a = new Army(*al->getArmy(p->getArmyset(), 0), p);
 		s->push_back(a);
 		p->addStack(s);
+		//if we're on a city, change the allegiance of the stack
+		//and it's armies to that of the city
+		GameMap *gm = GameMap::getInstance();
+		if (gm->getTile(s->getPos())->getBuilding() == Maptile::CITY)
+		  {
+		    Citylist *clist = Citylist::getInstance();
+		    City *c = clist->getNearestCity(s->getPos());
+			if (s->getPlayer() != c->getPlayer())
+			  {
+			    //remove it from the old player's list of stacks
+			    s->getPlayer()->getStacklist()->remove(s);
+			    //and give it to the new player list of stacks
+			    c->getPlayer()->getStacklist()->push_back(s);
+			    //change the ownership of the stack
+			    s->setPlayer(c->getPlayer());
+			    //and all of it's armies
+			    for (Stack::iterator it = s->begin(); 
+				 it != s->end(); it++)
+			      (*it)->setPlayer(c->getPlayer());
+			  }
+	          }
 	    }
 
 	    break;
@@ -553,10 +550,11 @@ void EditorBigMap::change_map_under_cursor()
 			|| GameMap::getInstance()->getTile(Vector<int>(x, y))->getBuilding() != Maptile::NONE)
 		    {
 			city_placeable = false;
-			goto after_for;
+			break;
 		    }
+		    if (city_placeable == false)
+		      break;
 		}
-	after_for:
 	    if (!city_placeable)
 		break;
 	    
@@ -565,12 +563,6 @@ void EditorBigMap::change_map_under_cursor()
 	    c.setPlayer(Playerlist::getInstance()->getNeutral());
 	    Citylist::getInstance()->push_back(c);
 
-	    // find the index of the "grass" tile
-	    unsigned int index;
-	    for (index = 0; index < ts->size(); ++index)
-		if ((*ts)[index]->getType() == Tile::GRASS)
-		    break;
-        
 	    // notify the maptiles that a city has been placed here
 	    Rectangle r = c.get_area();
 	    for (int x = r.x; x < r.x + r.w; ++x)
@@ -578,13 +570,40 @@ void EditorBigMap::change_map_under_cursor()
 		{
 		    Maptile* t = GameMap::getInstance()->getTile(Vector<int>(x, y));
 		    t->setBuilding(Maptile::CITY);
-		    t->setType(index);
+		    t->setType(grass_index);
 		}
 
+	    //change allegiance of stacks under this city
+	    for (unsigned int x = 0; x < c.getSize(); x++)
+	      {
+		for (unsigned int y = 0; y < c.getSize(); y++)
+		  {
+		    Stack *s = Stacklist::getObjectAt(c.getPos().x + x, 
+						      c.getPos().y + y);
+		    if (s)
+		      {
+			if (s->getPlayer() != c.getPlayer())
+			  {
+			    //remove it from the old player's list of stacks
+			    s->getPlayer()->getStacklist()->remove(s);
+			    //and give it to the new player list of stacks
+			    c.getPlayer()->getStacklist()->push_back(s);
+			    //change the ownership of the stack
+			    s->setPlayer(c.getPlayer());
+			    //and all of it's armies
+			    for (Stack::iterator it = s->begin(); 
+				 it != s->end(); it++)
+			      (*it)->setPlayer(c.getPlayer());
+			  }
+		      }
+		  }
+    
+	      }
+
 	    // finally, smooth the surrounding map
-	    for (int x = r.x - 1; x < r.x + r.w + 1; ++x)
-		for (int y = r.y - 1; y < r.y + r.h + 1; ++y)
-		    d_renderer->smooth(x, y);
+	    GameMap::getInstance()->applyTileStyles(r.y - 1, r.x - 1, 
+						    r.y + r.h + 1, 
+						    r.x + r.w + 1, true);
 	}
 	break;
 	    
@@ -593,7 +612,14 @@ void EditorBigMap::change_map_under_cursor()
 		&& maptile->getMaptileType() != Tile::WATER)
 	    {
 		maptile->setBuilding(Maptile::RUIN);
+		maptile->setType(grass_index);
 		Ruinlist::getInstance()->push_back(Ruin(tile));
+		Rectangle r = Ruinlist::getInstance()->back().get_area();
+		// fixme, demote lone tiles, etc
+		GameMap::getInstance()->applyTileStyles(r.y - 1, r.x - 1, 
+							r.y + r.h + 1, 
+							r.x + r.w + 1, 
+							true);
 	    }
 	    break;
 	    
@@ -602,35 +628,25 @@ void EditorBigMap::change_map_under_cursor()
 		&& maptile->getMaptileType() != Tile::WATER)
 	    {
 		maptile->setBuilding(Maptile::TEMPLE);
+		maptile->setType(grass_index);
 		Templelist::getInstance()->push_back(Temple(tile));
+		Rectangle r = Templelist::getInstance()->back().get_area();
+		GameMap::getInstance()->applyTileStyles(r.y - 1, r.x - 1, 
+							r.y + r.h + 1, 
+							r.x + r.w + 1,
+							true);
 	    }
 	    break;
 	    
 	case SIGNPOST:
 	    if (maptile->getBuilding() == Maptile::NONE 
-		&& maptile->getMaptileType() != Tile::WATER)
+		&& maptile->getMaptileType() == Tile::GRASS)
 	    {
 		maptile->setBuilding(Maptile::SIGNPOST);
 		Signpostlist::getInstance()->push_back(Signpost(tile));
 	    }
 	    break;
 	    
-	case STONE:
-	    if ((maptile->getBuilding() == Maptile::NONE
-		 || maptile->getBuilding() == Maptile::STONE)
-		&& maptile->getMaptileType() == Tile::GRASS)
-	    {
-		int type = mouse_pos_to_stone_type(mouse_pos);
-		if (maptile->getBuilding() == Maptile::STONE)
-		    Stonelist::getInstance()->getObjectAt(tile)->setType(type);
-		else
-		{
-		    maptile->setBuilding(Maptile::STONE);
-		    Stonelist::getInstance()->push_back(Stone(tile, "", type));
-		}
-	    }
-	    break;
-	    
 	case PORT:
 	    if (maptile->getBuilding() == Maptile::NONE 
 		&& maptile->getMaptileType() != Tile::WATER)
@@ -660,7 +676,7 @@ void EditorBigMap::change_map_under_cursor()
 	case ROAD:
 	    if ((maptile->getBuilding() == Maptile::NONE
 		 || maptile->getBuilding() == Maptile::ROAD)
-		&& maptile->getMaptileType() == Tile::GRASS)
+		&& maptile->getMaptileType() != Tile::WATER)
 	    {
 		int type = tile_to_road_type(tile);
 		if (maptile->getBuilding() == Maptile::NONE)
@@ -698,3 +714,9 @@ void EditorBigMap::change_map_under_cursor()
     draw();
 }
 
+void EditorBigMap::smooth_view()
+{
+  GameMap::getInstance()->applyTileStyles(view.y, view.x, view.y+view.h, 
+					  view.x+view.w, true);
+  draw();
+}
