@@ -28,12 +28,10 @@
 #include "ruinlist.h"
 #include "signpostlist.h"
 #include "templelist.h"
-#include "stonelist.h"
 #include "roadlist.h"
 #include "ruin.h"
 #include "signpost.h"
 #include "temple.h"
-#include "stone.h"
 #include "road.h"
 #include "playerlist.h"
 #include "defs.h"
@@ -62,7 +60,7 @@ GameBigMap::GameBigMap()
   mouse_state = NONE;
   input_locked = false;
 
-  d_arrows = File::getMiscPicture("arrows.png");
+  d_waypoints = File::getMiscPicture("waypoints.png");
   prev_mouse_pos = Vector<int>(0, 0);
 
   // setup timeout
@@ -70,11 +68,12 @@ GameBigMap::GameBigMap()
     Timing::instance().register_timer(
 				      sigc::mem_fun(*this, &GameBigMap::on_selection_timeout),
 				      selection_timeout);
+  shift_key_is_down = false;
 }
 
 GameBigMap::~GameBigMap()
 {
-  SDL_FreeSurface(d_arrows);
+  SDL_FreeSurface(d_waypoints);
 }
 
 void GameBigMap::select_active_stack()
@@ -89,8 +88,6 @@ void GameBigMap::select_active_stack()
       cerr << _("original path of stack was blocked\n");
     }
 
-  center_view(stack->getPos());
-
   stack_selected.emit(stack);
 }
 
@@ -123,6 +120,13 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 
       if (stack)
 	{
+	  // ask for military advice
+	  if (d_cursor == GraphicsCache::QUESTION)
+	    {
+	      Playerlist::getActiveplayer()->stackFightAdvise(stack, tile); 
+	      set_shift_key_down (false);
+	      return;
+	    }
 	  Vector<int> p;
 	  p.x = tile.x; p.y = tile.y;
 
@@ -311,57 +315,8 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
     }
 }
 
-void GameBigMap::mouse_motion_event(MouseMotionEvent e)
+void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 {
-  static Vector<int> last_tile;
-  if (input_locked)
-    return;
-
-  // drag with left mouse button
-  if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
-      && (mouse_state == NONE || mouse_state == DRAGGING))
-    {
-      Vector<int> delta = -(e.pos - prev_mouse_pos);
-
-      // ignore very small drags to ensure that a shaking mouse does not
-      // prevent the user from making right clicks
-      if (mouse_state == NONE && length(delta) <= 2)
-	return;
-
-      // FIXME: show a drag cursor
-
-      int ts = GameMap::getInstance()->getTileSet()->getTileSize();
-      SDL_Surface *screen = SDL_GetVideoSurface();
-      Vector<int> screen_dim(screen->w, screen->h);
-      view_pos = clip(Vector<int>(0, 0),
-		      view_pos + delta,
-		      GameMap::get_dim() * ts - screen_dim);
-
-      // calculate new view position in tiles, rounding up
-      Vector<int> new_view = (view_pos + Vector<int>(ts - 1, ts - 1)) / ts;
-
-      bool redraw_buffer = false;
-
-      if (new_view != view.pos)
-	{
-	  view.x = new_view.x;
-	  view.y = new_view.y;
-	  view_changed.emit(view);
-	  redraw_buffer = true;
-	}
-
-      draw(redraw_buffer);
-      mouse_state = DRAGGING;
-    }
-
-  // the following block of code shows the correct mouse cursor
-  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
-  Vector<int> tile = mouse_pos_to_tile(e.pos);
-  if (tile == last_tile)
-    {
-      prev_mouse_pos = e.pos;
-      return;
-    }
   if (stack)
     {
       d_cursor = GraphicsCache::FEET;
@@ -383,11 +338,16 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 		    delta = abs(tile.y - stack->getPos().y);
 		  if (delta <= 1)
 		    {
-		      bool friendly = false;
-		      if (friendly)
-			d_cursor = GraphicsCache::HEART;
+		      if (is_shift_key_down())
+			d_cursor = GraphicsCache::QUESTION;
 		      else
-			d_cursor = GraphicsCache::SWORD;
+			{
+			  bool friendly = false;
+			  if (friendly)
+			    d_cursor = GraphicsCache::HEART;
+			  else
+			    d_cursor = GraphicsCache::SWORD;
+			}
 		    }
 		  else
 		    {
@@ -427,11 +387,16 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 			delta = abs(stack->getPos().y - st->getPos().y);
 		      if (delta <= 1)
 			{
-			  bool friendly = false;
-			  if (friendly)
-			    d_cursor = GraphicsCache::HEART;
+			  if (is_shift_key_down())
+		    	    d_cursor = GraphicsCache::QUESTION;
 			  else
-			    d_cursor = GraphicsCache::SWORD;
+			    {
+			      bool friendly = false;
+			      if (friendly)
+				d_cursor = GraphicsCache::HEART;
+			      else
+				d_cursor = GraphicsCache::SWORD;
+			    }
 			}
 		      else
 			d_cursor = GraphicsCache::HAND;
@@ -475,6 +440,58 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 
     }
   cursor_changed.emit(d_cursor);
+}
+
+void GameBigMap::mouse_motion_event(MouseMotionEvent e)
+{
+  static Vector<int> last_tile;
+  if (input_locked)
+    return;
+
+  // drag with left mouse button
+  if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
+      && (mouse_state == NONE || mouse_state == DRAGGING))
+    {
+      Vector<int> delta = -(e.pos - prev_mouse_pos);
+
+      // ignore very small drags to ensure that a shaking mouse does not
+      // prevent the user from making right clicks
+      if (mouse_state == NONE && length(delta) <= 2)
+	return;
+
+      int ts = GameMap::getInstance()->getTileSet()->getTileSize();
+      SDL_Surface *screen = SDL_GetVideoSurface();
+      Vector<int> screen_dim(screen->w, screen->h);
+      view_pos = clip(Vector<int>(0, 0),
+		      view_pos + delta,
+		      GameMap::get_dim() * ts - screen_dim);
+
+      // calculate new view position in tiles, rounding up
+      Vector<int> new_view = (view_pos + Vector<int>(ts - 1, ts - 1)) / ts;
+
+      bool redraw_buffer = false;
+
+      if (new_view != view.pos)
+	{
+	  view.x = new_view.x;
+	  view.y = new_view.y;
+	  view_changed.emit(view);
+	  redraw_buffer = true;
+	}
+
+      draw(redraw_buffer);
+      mouse_state = DRAGGING;
+    }
+
+  // the following block of code shows the correct mouse cursor
+  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
+  Vector<int> tile = mouse_pos_to_tile(e.pos);
+  if (tile == last_tile)
+    {
+      prev_mouse_pos = e.pos;
+      return;
+    }
+  determine_mouse_cursor (stack, tile);
 
   prev_mouse_pos = e.pos;
   last_tile = tile;
@@ -491,54 +508,39 @@ void GameBigMap::after_draw()
   if (stack && stack->getPath()->size())
     {
       Vector<int> pos;
-      Vector<int> nextpos;
       SDL_Color c;
       c.r = c.g = c.b = 0;
 
-      // draw all waypoints except the last
+      // draw all waypoints
+      Uint32 pathcount = 0;
+      bool canMoveThere = true;
       for (list<Vector<int>*>::iterator it = stack->getPath()->begin();
-	   it != --(stack->getPath()->end());)
+	   it != stack->getPath()->end(); it++)
 	{
-	  // peak at the next waypoint to draw the correct arrow
+	  size_t wpsize = 40; //waypoint images are always 40x40
 	  pos = tile_to_buffer_pos(**it);
-	  nextpos = tile_to_buffer_pos(**(++it));
 	  SDL_Rect r1, r2;
 	  r1.y = 0;
-	  r1.w = r1.h = tilesize;
-	  r2.x = pos.x;
-	  r2.y = pos.y;
-	  r2.w = r2.h = tilesize;
+	  r1.w = r1.h = wpsize; 
+	  int offset = (tilesize - wpsize) / 2;
+	  if (offset < 0)
+	    offset = 0;
+	  r2.x = pos.x + offset;
+	  r2.y = pos.y + offset;
+	  r2.w = r2.h = wpsize;
 
-	  if (nextpos.x == pos.x && nextpos.y < pos.y)
+	  //fixme: check to see if we can move here
+	  canMoveThere = (pathcount < stack->getMovesExhaustedAtPoint());
+	  if (canMoveThere)
 	    r1.x = 0;
-	  else if (nextpos.x > pos.x && nextpos.y < pos.y)
-	    r1.x = tilesize;
-	  else if (nextpos.x > pos.x && nextpos.y == pos.y)
-	    r1.x = 2 * tilesize;
-	  else if (nextpos.x > pos.x && nextpos.y > pos.y)
-	    r1.x = 3 * tilesize;
-	  else if (nextpos.x == pos.x && nextpos.y > pos.y)
-	    r1.x = 4 * tilesize;
-	  else if (nextpos.x < pos.x && nextpos.y > pos.y)
-	    r1.x = 5 * tilesize;
-	  else if (nextpos.x < pos.x && nextpos.y == pos.y)
-	    r1.x = 6 * tilesize;
-	  else if (nextpos.x < pos.x && nextpos.y < pos.y)
-	    r1.x = 7 * tilesize;
+	  else
+	    r1.x = wpsize;
 
-	  SDL_BlitSurface(d_arrows, &r1, buffer, &r2);
+	  SDL_BlitSurface(d_waypoints, &r1, buffer, &r2);
+	  pathcount++;
 
 	}
 
-      pos = tile_to_buffer_pos(*stack->getPath()->back());
-      SDL_Rect r1, r2;
-      r1.x = 8 * tilesize;
-      r1.y = 0;
-      r1.w = r1.h = tilesize;
-      r2.x = pos.x;
-      r2.y = pos.y;
-      r2.w = r2.h = tilesize;
-      SDL_BlitSurface(d_arrows, &r1, buffer, &r2);
     }
 
   if (stack)
@@ -570,7 +572,7 @@ void GameBigMap::after_draw()
 	      if ((*it)->isGrouped())
 		num_selected++;
 	    }
-			
+
 	  draw_stack (stack);
 	  if (num_selected > 1)
 	    tmp = gc->getSelectorPic(0, bigframe, stack->getPlayer());
@@ -580,3 +582,38 @@ void GameBigMap::after_draw()
 	}
     }
 }
+
+void GameBigMap::set_shift_key_down (bool down)
+{
+  if (GameScenario::s_military_advisor == false)
+    return;
+  static GraphicsCache::CursorType prev_cursor = GraphicsCache::HEART;
+
+  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
+  if (!stack)
+    return;
+
+  if (d_cursor == GraphicsCache::HEART ||
+      d_cursor == GraphicsCache::SWORD)
+    {
+      if (shift_key_is_down == false)
+	{
+	  shift_key_is_down = down;
+	  prev_cursor = d_cursor;
+	  d_cursor = GraphicsCache::QUESTION;
+	  cursor_changed.emit(d_cursor);
+	}
+    }
+  else if (d_cursor == GraphicsCache::QUESTION)
+    {
+      if (shift_key_is_down == true)
+	{
+	  shift_key_is_down = down;
+	  d_cursor = prev_cursor;
+	  cursor_changed.emit(d_cursor);
+	}
+    }
+  else
+    shift_key_is_down = down;
+}
+
