@@ -127,13 +127,20 @@ GamePreferencesDialog::GamePreferencesDialog()
     // fill in tile themes combobox
     tile_theme_combobox = manage(new Gtk::ComboBoxText);
     
+    Uint32 default_id = 0;
+    Uint32 counter = 0;
     Tilesetlist *tl = Tilesetlist::getInstance();
     std::list<std::string> tile_themes = tl->getNames();
     for (std::list<std::string>::iterator i = tile_themes.begin(),
 	     end = tile_themes.end(); i != end; ++i)
+      {
+	if (*i == "Default")
+	  default_id = counter;
 	tile_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+	counter++;
+      }
 
-    tile_theme_combobox->set_active(0);
+    tile_theme_combobox->set_active(default_id);
 
     Gtk::Box *box;
     xml->get_widget("tile_theme_box", box);
@@ -144,13 +151,18 @@ GamePreferencesDialog::GamePreferencesDialog()
     
     Armysetlist *al = Armysetlist::getInstance();
     std::list<std::string> army_themes = al->getNames();
+    counter = 0;
+    default_id = 0;
     for (std::list<std::string>::iterator i = army_themes.begin(),
 	     end = army_themes.end(); i != end; ++i)
       {
+	if (*i == "Default")
+	  default_id = counter;
 	army_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+	counter++;
       }
 
-    army_theme_combobox->set_active(0);
+    army_theme_combobox->set_active(default_id);
 
     xml->get_widget("army_theme_box", box);
     box->pack_start(*army_theme_combobox, Gtk::PACK_SHRINK);
