@@ -35,14 +35,15 @@ using namespace std;
 
 Stack::Stack(Player* player, Vector<int> pos)
     : Object(pos), d_player(player), d_defending(false), d_parked(false),
-    d_deleting(false)
+    d_deleting(false), d_moves_exhausted_at_point(0)
 {
     d_path = new Path();
 }
 
 Stack::Stack(Stack& s)
     : Object(s), d_player(s.d_player), d_defending(s.d_defending),
-     d_parked(s.d_parked), d_deleting(false)
+     d_parked(s.d_parked), d_deleting(false),
+     d_moves_exhausted_at_point(s.d_moves_exhausted_at_point)
 {
     clear();
     d_path = new Path();
@@ -77,6 +78,7 @@ Stack::Stack(XML_Helper* helper)
   else
     d_player = Playerlist::getInstance()->getPlayer(i);
 
+  helper->getData(d_moves_exhausted_at_point, "moves_exhausted_at_point");
 
   helper->registerTag("path", sigc::mem_fun((*this), &Stack::load));
   helper->registerTag("army", sigc::mem_fun((*this), &Stack::load));
@@ -113,6 +115,9 @@ bool Stack::moveOneStep()
   //now remove first point of the path
   d_path->flErase(d_path->begin());
 
+  //and decrement the point at which we exhaust our path
+  if (getMovesExhaustedAtPoint())
+    setMovesExhaustedAtPoint(getMovesExhaustedAtPoint()-1);
   return true;
 }
 
@@ -366,7 +371,7 @@ Uint32 Stack::getMaxSight() const
 void Stack::nextTurn()
 {
   setParked(false);
-  for (iterator it = begin(); it != end(); it++)
+  for (iterator it = begin(); it != end(); ++it)
     {
       (*it)->resetMoves();
       // TODO: should be moved in a more appropriate place => class Player
@@ -397,6 +402,8 @@ void Stack::nextTurn()
       }
   if (d_defending == true)
     setFortified(true);
+  //recalculate paths
+  getPath()->recalculate(this);
 }
 
 bool Stack::save(XML_Helper* helper) const
@@ -414,6 +421,9 @@ bool Stack::save(XML_Helper* helper) const
   retval &= helper->saveData("defending", d_defending);
   retval &= helper->saveData("parked", d_parked);
 
+  retval &= helper->saveData("moves_exhausted_at_point", 
+			     d_moves_exhausted_at_point);
+
   //save path
   retval &= d_path->save(helper);
 
@@ -481,7 +491,7 @@ Uint32 Stack::calculateMoveBonus() const
   int num_landedother = 0;
   if (size() == 0)
     return 0;
-  for (Stack::const_iterator it = this->begin(); it != this->end(); it++)
+  for (const_iterator it = this->begin(); it != this->end(); it++)
     {
       if ((*it)->isGrouped() == false)
 	continue;
@@ -514,7 +524,8 @@ Uint32 Stack::calculateMoveBonus() const
     {
       if ((*it)->isHero())
 	{
-	  std::list<Item*> backpack = dynamic_cast<Hero*>((*it))->getBackpack();
+	  Hero *h = dynamic_cast<Hero*>(*it);
+	  std::list<Item*> backpack = h->getBackpack();
 	  std::list<Item*>::const_iterator item;
 	  for (item = backpack.begin(); item != backpack.end(); item++)
 	    {
@@ -624,4 +635,11 @@ bool Stack::getFortified()
   return false;
 }
 
+Uint32 Stack::getUpkeep()
+{
+  Uint32 upkeep = 0;
+  for (iterator it = begin(); it != end(); it++)
+    upkeep += (*it)->getUpkeep();
+  return upkeep;
+}
 // End of file
