@@ -78,6 +78,9 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
         //! Returns the number of stacks owned by all players
         static unsigned int getNoOfStacks();
 
+        //! Returns the number of armies in the list
+        unsigned int countArmies();
+
         /** Sets the activestack. The purpose of this pointer is that the
           * activestack is assumed to be one the player is currently "touching".
           * Several functions use this feature for internal purposes, so don't
@@ -87,12 +90,6 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
           */
         void setActivestack(Stack* activestack) {d_activestack = activestack;}
 
-        //! Get the previous non-defending stack in the list and mark it as active.
-        Stack* setPrev();
-
-        //! Get the next non-defending stack in the list and mark it as active.
-        Stack* setNext();
-
         //! Get the next non-defending stack that can move.
         Stack* getNextMovable();
 
@@ -121,6 +118,10 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
         //! Behaves like std::list::remove(), but frees pointers as well
         bool flRemove(Stack* object);
 
+        //! Return the stack at position (x,y) or 0 if there is none
+	//! only operates on this stacklist, and not all players stacklists.
+        Stack* getOwnObjectAt(int x, int y);
+
     private:
         //! Callback function for loading
         bool load(std::string tag, XML_Helper* helper);
